===========
Scikit-Qfit
===========

This is the documentation of **Scikit-Qfit**.

.. note::

    This is the main page of your project's `Sphinx <http://sphinx-doc.org/>`_
    documentation. It is formatted in `reStructuredText
    <http://sphinx-doc.org/rest.html>`__. Add additional pages by creating
    rst-files in ``docs`` and adding them to the `toctree
    <http://sphinx-doc.org/markup/toctree.html>`_ below. Use then
    `references <http://sphinx-doc.org/markup/inline.html>`__ in order to link
    them from this page, e.g. :ref:`authors <authors>` and :ref:`changes`.
    It is also possible to refer to the documentation of other Python packages
    with the `Python domain syntax
    <http://sphinx-doc.org/domains.html#the-python-domain>`__. By default you
    can reference the documentation of `Sphinx <http://sphinx.pocoo.org>`__,
    `Python <http://docs.python.org/>`__, `matplotlib
    <http://matplotlib.sourceforge.net>`__, `NumPy
    <http://docs.scipy.org/doc/numpy>`__, `Scikit-Learn
    <http://scikit-learn.org/stable>`__, `Pandas
    <http://pandas.pydata.org/pandas-docs/stable>`__, `SciPy
    <http://docs.scipy.org/doc/scipy/reference/>`__. You can add more by
    extending the ``intersphinx_mapping`` in your Sphinx's ``conf.py``.

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Changelog <changes>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
